LaTeX with Latexmk and Gitlab CI
=================


Why we need to use that
-----------------------

It is annoying to have non-compiling LaTeX files flying around. By using
continuous integration (CI) we are sure that we know at least one environment on
which the LaTeX file compiles. This is very helpful for you, your supervisor and
your fellow colleagues.


How to use it (Setup)
-------------

- Create a blank git repository in `ift/papers` on Gitlab. Let us call it `my-awesome-project`.
- Clone the default repository and change its remote to your new repository:
```bash
git clone git@gitlab.mpcdf.mpg.de:ift/papers/exemplary-latex-repo.git
git remote set-url origin git@gitlab.mpcdf.mpg.de:ift/papers/my-awesome-project.git
git push -u origin master
```

- Finally, you should rename the folder name.
```bash
cd ..
mv exemplary-latex-repo my-awesome-project
```

- Adapt the settings in the `latexmkrc` configuration file, especially the name of the main tex file, to your needs.

- Optional: The continuous integration is configured in the `.gitlab-ci.yml` file. Here you could add more builds or test scripts if needed.


Compile and find your pdf file offline
--------------------------------------

The build is based on latexmk. Thus after setting your main tex file in the `latexmkrc` file, simply call:
```bash
latexmk
```
in your project directory. This will call `pdflatex`, `bibtext` and `biber` as often as necessary, until all references are resolved. There is no need for a second iteration.

The build files can then be found in the `build` directory, to keep them separated from the source.

**Tipps**: Use latexmk with preview and continuous build on change:
```bash
latexmk -pvc
```
or clean your auxiliary files with:

```bash
latexmk -c
```



Find your compiled pdf file online
----------------------------------

After a push, go to your [project's main page](https://gitlab.mpcdf.mpg.de/ift/papers/exemplary-latex-repo),
find the download button and click `Download build`.

A second way is the following:
- Go to the repo's [summary of pipelines](https://gitlab.mpcdf.mpg.de/ift/papers/exemplary-latex-repo/pipelines) (CI -> Pipelines).
- Find your latest commit. Click on the status button (either a green `passed` or a red `failed`).
- Click on `build`.
- If your build has failed, find your bug, correct it locally on your computer, commit it, push it to gitlab and check again.
- If your build has succeeded, click on the right-hand side on either `Download` or `Browse` to find your compiled pdf file.


If something does not work
--------------------------

If your LaTeX file really does not compile, adapt your `.gitlab-ci.yml` and `latexmkrc` file
and install all necessary packages. If you need help with that, feel free to
contact Philipp (parras@mpa-garching.mpg.de) or visit him in his office.
